@@ -17,7 +17,7 @@
 set -e
 set -o pipefail
 
-KUBERNETES_VERSION=v1.15.3
+KUBERNETES_VERSION=v1.17.3
 KUBE_STATE_METRICS_LOG_DIR=./log
 KUBE_STATE_METRICS_IMAGE_NAME='quay.io/coreos/kube-state-metrics'
 PROMETHEUS_VERSION=2.12.0
@@ -28,6 +28,9 @@ MINIKUBE_VERSION=v1.3.1
 MINIKUBE_DRIVER=${MINIKUBE_DRIVER:-virtualbox}
 SUDO=${SUDO:-}
 
+OS=$(uname -s | awk '{print tolower($0)}')
+OS=${OS:-linux}
+
 EXCLUDED_RESOURCE_REGEX="verticalpodautoscaler"
 
 mkdir -p ${KUBE_STATE_METRICS_LOG_DIR}
@@ -36,27 +39,27 @@ function finish() {
     echo "calling cleanup function"
     # kill kubectl proxy in background
     kill %1 || true
-    kubectl delete -f kubernetes/ || true
+    kubectl delete -f examples/standard/ || true
     kubectl delete -f tests/manifests/ || true
 }
 
 function setup_minikube() {
-    curl -sLo minikube https://storage.googleapis.com/minikube/releases/${MINIKUBE_VERSION}/minikube-linux-amd64 \
+    curl -sLo minikube https://storage.googleapis.com/minikube/releases/${MINIKUBE_VERSION}/minikube-"${OS}"-amd64 \
         && chmod +x minikube \
         && ${SUDO} mv minikube /usr/local/bin/
 }
 
 function setup_kubectl() {
-    curl -sLo kubectl https://storage.googleapis.com/kubernetes-release/release/"$(curl -s https://storage.googleapis.com/kubernetes-release/release/stable.txt)"/bin/linux/amd64/kubectl \
+    curl -sLo kubectl https://storage.googleapis.com/kubernetes-release/release/"$(curl -s https://storage.googleapis.com/kubernetes-release/release/stable.txt)"/bin/"${OS}"/amd64/kubectl \
         && chmod +x kubectl \
         && ${SUDO} mv kubectl /usr/local/bin/
 }
 
 function setup_promtool() {
-    wget -q -O /tmp/prometheus.tar.gz https://github.com/prometheus/prometheus/releases/download/v${PROMETHEUS_VERSION}/prometheus-${PROMETHEUS_VERSION}.linux-amd64.tar.gz
-    tar zxfv /tmp/prometheus.tar.gz -C /tmp/ prometheus-${PROMETHEUS_VERSION}.linux-amd64/promtool
-    ${SUDO} mv /tmp/prometheus-${PROMETHEUS_VERSION}.linux-amd64/promtool /usr/local/bin/
-    rmdir /tmp/prometheus-${PROMETHEUS_VERSION}.linux-amd64
+    wget -q -O /tmp/prometheus.tar.gz https://github.com/prometheus/prometheus/releases/download/v${PROMETHEUS_VERSION}/prometheus-${PROMETHEUS_VERSION}."${OS}"-amd64.tar.gz
+    tar zxfv /tmp/prometheus.tar.gz -C /tmp/ prometheus-${PROMETHEUS_VERSION}."${OS}"-amd64/promtool
+    ${SUDO} mv /tmp/prometheus-${PROMETHEUS_VERSION}."${OS}"-amd64/promtool /usr/local/bin/
+    rmdir /tmp/prometheus-${PROMETHEUS_VERSION}."${OS}"-amd64
     rm /tmp/prometheus.tar.gz
 }
 
@@ -113,21 +116,21 @@ docker images -a
 KUBE_STATE_METRICS_IMAGE_TAG=$(docker images -a|grep 'quay.io/coreos/kube-state-metrics'|grep -v 'latest'|awk '{print $2}'|sort -u)
 echo "local kube-state-metrics image tag: $KUBE_STATE_METRICS_IMAGE_TAG"
 
-# update kube-state-metrics image tag in kube-state-metrics-deployment.yaml
-sed -i.bak "s|${KUBE_STATE_METRICS_IMAGE_NAME}:v.*|${KUBE_STATE_METRICS_IMAGE_NAME}:${KUBE_STATE_METRICS_IMAGE_TAG}|g" ./kubernetes/kube-state-metrics-deployment.yaml
-cat ./kubernetes/kube-state-metrics-deployment.yaml
+# update kube-state-metrics image tag in deployment.yaml
+sed -i.bak "s|${KUBE_STATE_METRICS_IMAGE_NAME}:v.*|${KUBE_STATE_METRICS_IMAGE_NAME}:${KUBE_STATE_METRICS_IMAGE_TAG}|g" ./examples/standard/deployment.yaml
+cat ./examples/standard/deployment.yaml
 
 trap finish EXIT
 
 # set up kube-state-metrics manifests
-kubectl create -f ./kubernetes/kube-state-metrics-service-account.yaml
+kubectl create -f ./examples/standard/service-account.yaml
 
-kubectl create -f ./kubernetes/kube-state-metrics-cluster-role.yaml
-kubectl create -f ./kubernetes/kube-state-metrics-cluster-role-binding.yaml
+kubectl create -f ./examples/standard/cluster-role.yaml
+kubectl create -f ./examples/standard/cluster-role-binding.yaml
 
-kubectl create -f ./kubernetes/kube-state-metrics-deployment.yaml
+kubectl create -f ./examples/standard/deployment.yaml
 
-kubectl create -f ./kubernetes/kube-state-metrics-service.yaml
+kubectl create -f ./examples/standard/service.yaml
 
 kubectl create -f ./tests/manifests/
 
@@ -161,6 +164,11 @@ set -e
 
 echo "kube-state-metrics is up and running"
 
+echo "start e2e test for kube-state-metrics"
+KSMURL='http://localhost:8001/api/v1/namespaces/kube-system/services/kube-state-metrics:http-metrics/proxy'
+go test -v ./tests/e2e/ --ksmurl=${KSMURL}
+
+# TODO: re-implement the following test cases in Go with the goal of removing this file.
 echo "access kube-state-metrics metrics endpoint"
 curl -s "http://localhost:8001/api/v1/namespaces/kube-system/services/kube-state-metrics:http-metrics/proxy/metrics" >${KUBE_STATE_METRICS_LOG_DIR}/metrics
 
